/****************************************************************************
** Meta object code from reading C++ file 'indexeradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "indexeradaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'indexeradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14IndexerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto IndexerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN14IndexerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IndexerAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.Indexer",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Akonadi.Indexer\">\n    <metho"
        "d name=\"reindexAll\"/>\n    <method name=\"reindexCollection\">\n"
        "      <arg direction=\"in\" type=\"x\" name=\"item\"/>\n    </meth"
        "od>\n    <method name=\"indexedItems\">\n      <arg direction=\"in"
        "\" type=\"x\" name=\"item\"/>\n      <arg direction=\"out\" type=\""
        "x\"/>\n    </method>\n    <method name=\"numberOfCollectionQueued\""
        ">\n      <arg direction=\"out\" type=\"i\"/>\n    </method>\n    <"
        "method name=\"reindexCollections\">\n      <arg direction=\"in\" t"
        "ype=\"ax\" name=\"ids\"/>\n      <annotation value=\"const QList&l"
        "t;qlonglong&gt; &amp;\" name=\"org.qtproject.QtDBus.QtTypeName.In0"
        "\"/>\n    </method>\n    <signal name=\"collectionIndexingFinished"
        "\">\n      <arg direction=\"out\" type=\"x\" name=\"connectionId\""
        "/>\n    </signal>\n  </interface>\n",
        "collectionIndexingFinished",
        "",
        "connectionId",
        "indexedItems",
        "item",
        "numberOfCollectionQueued",
        "reindexAll",
        "reindexCollection",
        "reindexCollections",
        "QList<qlonglong>",
        "ids"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'collectionIndexingFinished'
        QtMocHelpers::SignalData<void(qlonglong)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Slot 'indexedItems'
        QtMocHelpers::SlotData<qlonglong(qlonglong)>(8, 6, QMC::AccessPublic, QMetaType::LongLong, {{
            { QMetaType::LongLong, 9 },
        }}),
        // Slot 'numberOfCollectionQueued'
        QtMocHelpers::SlotData<int()>(10, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'reindexAll'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reindexCollection'
        QtMocHelpers::SlotData<void(qlonglong)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 9 },
        }}),
        // Slot 'reindexCollections'
        QtMocHelpers::SlotData<void(const QList<qlonglong> &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<IndexerAdaptor, qt_meta_tag_ZN14IndexerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject IndexerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14IndexerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14IndexerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14IndexerAdaptorE_t>.metaTypes,
    nullptr
} };

void IndexerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IndexerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->collectionIndexingFinished((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 1: { qlonglong _r = _t->indexedItems((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qlonglong*>(_a[0]) = std::move(_r); }  break;
        case 2: { int _r = _t->numberOfCollectionQueued();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->reindexAll(); break;
        case 4: _t->reindexCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 5: _t->reindexCollections((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IndexerAdaptor::*)(qlonglong )>(_a, &IndexerAdaptor::collectionIndexingFinished, 0))
            return;
    }
}

const QMetaObject *IndexerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IndexerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14IndexerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int IndexerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void IndexerAdaptor::collectionIndexingFinished(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
