/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Indexer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "indexeradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class IndexerAdaptor
 */

IndexerAdaptor::IndexerAdaptor(AkonadiIndexingAgent *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

IndexerAdaptor::~IndexerAdaptor()
{
    // destructor
}

qlonglong IndexerAdaptor::indexedItems(qlonglong item)
{
    // handle method call org.freedesktop.Akonadi.Indexer.indexedItems
    return parent()->indexedItems(item);
}

int IndexerAdaptor::numberOfCollectionQueued()
{
    // handle method call org.freedesktop.Akonadi.Indexer.numberOfCollectionQueued
    return parent()->numberOfCollectionQueued();
}

void IndexerAdaptor::reindexAll()
{
    // handle method call org.freedesktop.Akonadi.Indexer.reindexAll
    parent()->reindexAll();
}

void IndexerAdaptor::reindexCollection(qlonglong item)
{
    // handle method call org.freedesktop.Akonadi.Indexer.reindexCollection
    parent()->reindexCollection(item);
}

void IndexerAdaptor::reindexCollections(const QList<qlonglong> & ids)
{
    // handle method call org.freedesktop.Akonadi.Indexer.reindexCollections
    parent()->reindexCollections(ids);
}


#include "moc_indexeradaptor.cpp"
