/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Indexer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef INDEXERADAPTOR_H
#define INDEXERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "agent.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Indexer
 */
class IndexerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Indexer")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Indexer\">\n"
"    <method name=\"reindexAll\"/>\n"
"    <method name=\"reindexCollection\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"item\"/>\n"
"    </method>\n"
"    <method name=\"indexedItems\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"item\"/>\n"
"      <arg direction=\"out\" type=\"x\"/>\n"
"    </method>\n"
"    <method name=\"numberOfCollectionQueued\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"reindexCollections\">\n"
"      <arg direction=\"in\" type=\"ax\" name=\"ids\"/>\n"
"      <annotation value=\"const QList&lt;qlonglong&gt; &amp;\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"    </method>\n"
"    <signal name=\"collectionIndexingFinished\">\n"
"      <arg direction=\"out\" type=\"x\" name=\"connectionId\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    IndexerAdaptor(AkonadiIndexingAgent *parent);
    ~IndexerAdaptor() override;

    inline AkonadiIndexingAgent *parent() const
    { return static_cast<AkonadiIndexingAgent *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    qlonglong indexedItems(qlonglong item);
    int numberOfCollectionQueued();
    void reindexAll();
    void reindexCollection(qlonglong item);
    void reindexCollections(const QList<qlonglong> & ids);
Q_SIGNALS: // SIGNALS
    void collectionIndexingFinished(qlonglong connectionId);
};

#endif
