// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "akonadiplugin_indexer_debug.h"


Q_LOGGING_CATEGORY(AKONADIPLUGIN_INDEXER_LOG, "org.kde.pim.akonadiplugin_indexer", QtInfoMsg)

