// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "akonadi_indexer_agent_calendar_debug.h"


Q_LOGGING_CATEGORY(AKONADI_INDEXER_AGENT_CALENDAR_LOG, "org.kde.pim.akonadi_indexer_agent.calendar", QtInfoMsg)

